import { AccessLevelList } from '../../shared/access-level';
import { PolicyStatement } from '../../shared';
import { aws_iam as iam } from "aws-cdk-lib";
/**
 * Statement provider for service [appstudio](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappstudio.html).
 *
 * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
 */
export declare class Appstudio extends PolicyStatement {
    servicePrefix: string;
    /**
     * Grants permission to describe the account's current status
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/API_GetAccountStatus.html
     */
    toGetAccountStatus(): this;
    /**
     * Grants permission to fetch status of a enablement job
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/API_GetEnablementJobStatus.html
     */
    toGetEnablementJobStatus(): this;
    /**
     * Grants permission to submit a enablement job
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/API_StartEnablementJob.html
     */
    toStartEnablementJob(): this;
    /**
     * Grants permission to rollback an enablement job
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/API_StartRollbackEnablementJob.html
     */
    toStartRollbackEnablementJob(): this;
    /**
     * Grants permission to start a team deployment
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/API_StartTeamDeployment.html
     */
    toStartTeamDeployment(): this;
    protected accessLevelList: AccessLevelList;
    /**
     * Statement provider for service [appstudio](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsappstudio.html).
     *
     */
    constructor(props?: iam.PolicyStatementProps);
}
